
## Alternative Scene Cut/Change Detection Programs

The following is a list of programs or commands also performing scene cut analysis of some kind on video files.  In the future, this may be replaced with a table comparing PySceneDetect's features with these various alternatives.

 - ffmpeg `blackframe` filter ([thanks @tonycpsu](https://github.com/Breakthrough/PySceneDetect/issues/7)) - threshold mode only
 - [Shotdetect](http://johmathe.name/shotdetect.html) - appears to be only for *NIX, content mode only
 - [Matlab Scene Change Detection](http://www.mathworks.com/help/vision/examples/scene-change-detection.html) - requires Matlab and Simulink/Computer Vision Toolbox, uses feature extraction and edge detection

This list is not guaranteed to be complete, although [additions/contributions are most welcome](../contributing.md).

